pub fn list_sessions() -> Result<Vec<SessionInfo>>Expand description
List all sessions, sorted by most recently updated. Uses a lightweight struct to skip deserializing the full message history.
pub fn list_sessions() -> Result<Vec<SessionInfo>>List all sessions, sorted by most recently updated. Uses a lightweight struct to skip deserializing the full message history.