pub struct Session {Show 15 fields
pub id: String,
pub title: String,
pub name: Option<String>,
pub model: String,
pub thinking_level: String,
pub system_prompt: Option<String>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub total_input_tokens: u64,
pub total_output_tokens: u64,
pub session_cost: f64,
pub api_messages: Vec<Value>,
pub abort_context: Option<String>,
pub parent_session: Option<String>,
pub compacted_into: Option<String>,
}Fields
id: Stringtitle: Stringname: Option<String>model: Stringthinking_level: Stringsystem_prompt: Option<String>created_at: DateTime<Utc>updated_at: DateTime<Utc>total_input_tokens: u64total_output_tokens: u64session_cost: f64api_messages: Vec<Value>abort_context: Option<String>Saved abort context — injected into the next user message on /continue
parent_session: Option<String>ID of the session this was compacted from (backward link)
compacted_into: Option<String>ID of the session created by compacting this one (forward link)
Implementations
Sourceimpl Session
impl Session
pub fn new( model: &str, thinking_level: &str, system_prompt: Option<&str>, ) -> Self
Sourcepub fn new_from_compaction(parent: &Session, summary: String) -> Self
pub fn new_from_compaction(parent: &Session, summary: String) -> Self
Create a new session from a compaction summary, linked to the parent.
Sourcepub fn auto_title(&mut self)
pub fn auto_title(&mut self)
Set title from the first user message if not already set
pub async fn save(&self) -> Result<()>
pub fn load(id: &str) -> Result<Self>
pub fn info(&self) -> SessionInfo
Sourcepub fn set_name(&mut self, name: &str) -> Result<()>
pub fn set_name(&mut self, name: &str) -> Result<()>
Assign a name to this session. Validates name, enforces uniqueness across sessions, and rejects collisions with existing chain names. Idempotent: re-applying the current name is a no-op.
pub fn clear_name(&mut self)