Module permissions

Module permissions 

Permission model for extensions.

Permissions are declared in the plugin manifest and enforced before delivering hook events. An extension without the required permission cannot subscribe to the corresponding hook.

Structs

PermissionSet
A set of permissions granted to an extension.

Enums

Permission
Permission flags an extension can request.