pub fn query(
namespace: &str,
q: &MemoryQuery,
) -> Result<Vec<MemoryRecord>, MemoryError>Expand description
Query records in a namespace, applying filters, returning most-recent-first up to limit.
pub fn query(
namespace: &str,
q: &MemoryQuery,
) -> Result<Vec<MemoryRecord>, MemoryError>Query records in a namespace, applying filters, returning most-recent-first up to limit.