pub struct SubagentHandle {
pub id: String,
pub agent_name: String,
pub task_preview: String,
pub model: String,
pub system_prompt: String,
pub started_at: Instant,
pub timeout_secs: u64,
/* private fields */
}Fields
id: Stringagent_name: Stringtask_preview: Stringmodel: Stringsystem_prompt: Stringstarted_at: Instanttimeout_secs: u64Implementations
Sourceimpl SubagentHandle
impl SubagentHandle
Sourcepub fn new(
id: String,
agent_name: String,
task_preview: String,
model: String,
system_prompt: String,
timeout_secs: u64,
state: Arc<RwLock<SubagentState>>,
steer_tx: Option<UnboundedSender<String>>,
shutdown_tx: Option<Sender<()>>,
result_rx: Option<Receiver<SubagentResult>>,
) -> Self
pub fn new( id: String, agent_name: String, task_preview: String, model: String, system_prompt: String, timeout_secs: u64, state: Arc<RwLock<SubagentState>>, steer_tx: Option<UnboundedSender<String>>, shutdown_tx: Option<Sender<()>>, result_rx: Option<Receiver<SubagentResult>>, ) -> Self
Construct a new handle. The state Arc is shared with the spawned subagent thread.
Sourcepub fn status(&self) -> SubagentStatus
pub fn status(&self) -> SubagentStatus
Current status snapshot.
Sourcepub fn partial_output(&self) -> String
pub fn partial_output(&self) -> String
Partial output accumulated so far.
Sourcepub fn conversation_state(&self) -> Vec<Value>
pub fn conversation_state(&self) -> Vec<Value>
Snapshot of conversation state (for resume).
Sourcepub fn elapsed_secs(&self) -> f64
pub fn elapsed_secs(&self) -> f64
Seconds since this handle was created.
Sourcepub fn steer(&self, message: &str) -> Result<(), String>
pub fn steer(&self, message: &str) -> Result<(), String>
Send a steering message into the running subagent.
Sourcepub fn set_thread_handle(&mut self, handle: JoinHandle<()>)
pub fn set_thread_handle(&mut self, handle: JoinHandle<()>)
Signal the subagent to shut down. Store the OS thread handle for graceful shutdown.
pub fn cancel(&mut self)
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
True if the subagent is no longer running.
Sourcepub async fn collect(self) -> Result<SubagentResult, String>
pub async fn collect(self) -> Result<SubagentResult, String>
Consume the handle and wait for the final result.