register

Function register 

pub async fn register(
    tools: &Arc<RwLock<ToolRegistry>>,
    config: &SynapsConfig,
) -> (Arc<CommandRegistry>, Arc<RwLock<KeybindRegistry>>)
Load all skills, apply disable filters, build the command registry, build the keybind registry, and register the load_skill tool. Returns (command_registry, keybind_registry).