pub struct SecretPromptHandle { /* private fields */ }Expand description
UI-only secret prompt plumbing for interactive tools.
Secrets sent through this channel are never part of tool parameters, tool results, chat messages, or API messages. The TUI owns the input UI and sends only the final secret bytes back to the waiting tool.
Implementations
Sourceimpl SecretPromptHandle
impl SecretPromptHandle
pub fn new(tx: UnboundedSender<SecretPromptRequest>) -> Self
pub async fn prompt(&self, title: String, prompt: String) -> Option<String>