Skip to main contentCrate synaps_cli
Source pub use core::config;pub use core::session;pub use core::auth;pub use core::logging;pub use core::protocol;pub use core::error;pub use core::watcher_types;pub use core::models;pub use core::chain;pub use runtime::Runtime;pub use runtime::StreamEvent;pub use runtime::LlmEvent;pub use runtime::SessionEvent;pub use runtime::AgentEvent;pub use tools::Tool;pub use tools::ToolContext;pub use tools::ToolRegistry;pub use session::Session;pub use session::SessionInfo;pub use session::find_session;pub use session::latest_session;pub use session::list_sessions;pub use session::resolve_session;pub use session::find_session_by_name;pub use session::validate_name;pub use error::RuntimeError;pub use error::Result;pub use config::SynapsConfig;pub use config::load_config;pub use config::resolve_system_prompt;pub use watcher_types::AgentConfig;pub use watcher_types::SessionLimits;pub use watcher_types::HandoffState;pub use watcher_types::ExitReason;pub use watcher_types::SessionStats;pub use watcher_types::WatcherCommand;pub use watcher_types::WatcherResponse;pub use watcher_types::AgentStatusInfo;
- core
- Core infrastructure — config, session, auth, logging, error types, protocol.
- events
- Event Bus — universal message ingestion for agent sessions.
- extensions
- Extension system for SynapsCLI.
- help
- mcp
- MCP (Model Context Protocol) integration — JSON-RPC client, tool bridging, lazy loading.
- memory
- Local-first memory store.
- runtime
- sidecar
- Sidecar plugin support: long-running plugin processes that stream
events into the host over a JSONL line protocol.
- skills
- Skills and plugins subsystem.
- toast
- Public toast notification primitives for extensions and host UIs.
- tools
- Tool system — trait, registry, and built-in tool implementations.
- CancellationToken
- A token which can be used to signal a cancellation request to one or more
tasks.
- Value
- Represents any valid JSON value.
- epoch_millis
- Current time as Unix epoch milliseconds. Panics only if system clock is before 1970.
- epoch_secs
- Current time as Unix epoch seconds.
- flush_stderr
- Flush stderr, ignoring errors (pipe closed, etc.)
- flush_stdout
- Flush stdout, ignoring errors (pipe closed, etc.)
- truncate_str
- Truncate a string to at most
max bytes at a valid UTF-8 boundary.