Module session

Module session 

Structs

Session
SessionInfo
Lightweight info for listing sessions without loading full message history

Functions

find_session
Find a session by full or partial ID match
find_session_by_name
Find a session by its assigned name (not partial ID).
latest_session
Load the most recently updated session
list_sessions
List all sessions, sorted by most recently updated. Uses a lightweight struct to skip deserializing the full message history.
resolve_session
Resolve a query string to a Session. Resolution order:
validate_name
Validate a session or chain name: [a-z0-9-]{1,40}.